@@ -1,4 +1,4 @@
-from dagster._core.utils import check_dagster_package_version
+from dagster._core.libraries import DagsterLibraryRegistry
 
 from .snowflake_pyspark_type_handler import (
     SnowflakePySparkTypeHandler as SnowflakePySparkTypeHandler,
@@ -6,4 +6,4 @@ from .snowflake_pyspark_type_handler import (
 )
 from .version import __version__ as __version__
 
-check_dagster_package_version("dagster-snowflake-pyspark", __version__)
+DagsterLibraryRegistry.register("dagster-snowflake-pyspark", __version__)
